@@ -15,6 +15,7 @@ from typing import Sequence, Iterable, Dict
 
 from . import categories, bibexport, util
 from .config import Config
+from .version import __version__
 
 Category = namedtuple("Category", ["name", "link"])
 
@@ -151,12 +152,14 @@ def bibtex_to_html(entry):
 def authors_to_html(entry, config: Config):
     try:
         authors = get_authors(entry)
-        authors_html = _get_list(authors, css_class="author", config=config) + "."
+        authors_html = (
+            _get_list_of_names(authors, css_class="author", config=config) + "."
+        )
     except KeyError:
         try:
             authors = get_editors(entry)
             authors_html = (
-                _get_list(authors, css_class="author", config=config)
+                _get_list_of_names(authors, css_class="author", config=config)
                 + ", editors"
                 + "."
             )
@@ -171,7 +174,7 @@ def editors_to_html(entry, config: Config):
     try:
         editors = get_editors(entry)
         editors_html = (
-            _get_list(editors, css_class="editor", config=config) + ", editors"
+            _get_list_of_names(editors, css_class="editor", config=config) + ", editors"
         )
     except KeyError:
         editors_html = ""
@@ -194,8 +197,13 @@ def funders_to_html(entry):
     return f'<span class="funding-list">Funding:\n{indent(1, funders_html)}\n</span>'
 
 
-def _get_list(
-    elems,
+def _name_to_html(name):
+    first_name, last_name = util.split_name(name)
+    return f'<span class="firstname">{first_name}</span> <span class="lastname">{last_name}</span>'
+
+
+def _get_list_of_names(
+    names,
     *,
     css_class,
     config: Config,
@@ -203,10 +211,11 @@ def _get_list(
     delimiter_last=" and\n",
 ):
     ls = list()
-    for a in elems:
+    for a in names:
+        html_a = _name_to_html(a)
         if config.index_author(a):
-            a = f'<a href="../Author/{_author_to_link(a)}">{a}</a>'
-        ls.append(f'<span class="{css_class}">{a}</span>')
+            html_a = f'<a href="../Author/{_author_to_link(a)}">{html_a}</a>'
+        ls.append(f'<span class="{css_class}">{html_a}</span>')
     if len(ls) > 2:
         ls = [delimiter_intermediate.join(ls[:-1]), ls[-1]]
         if not delimiter_last.startswith(","):
@@ -486,14 +495,23 @@ def write(
     output_file = Path(output_file)
     output_file.parent.mkdir(exist_ok=True, parents=True)
     with open(output_file, "w") as outp:
+        html = []
         if head:
-            outp.write(head)
-        outp.writelines(
-            (
-                f"{line}\n"
-                for line in writes(entries, config=config, header_title=header_title)
-            )
-        )
+            html.append(head)
+        html += [
+            f"{line}\n"
+            for line in writes(entries, config=config, header_title=header_title)
+        ]
+        write_html(outp, html)
+
+
+def write_html(output_obj, html_lines):
+    start = f"<!-- This file was generated by pybib2web, version {__version__}: https://gitlab.com/sosy-lab/software/pybib2web/ -->"
+
+    end = f'<footer id="generator">This file was generated by <a href="https://gitlab.com/sosy-lab/software/pybib2web/">pybib2web</a>, version {__version__}</footer>'
+    output_obj.write(start)
+    output_obj.writelines(html_lines)
+    output_obj.write(end)
 
 
 def _get_header(header, show_link_to_index=True, show_link_to_all=True):
@@ -530,7 +548,10 @@ def write_html_tree(entries: Sequence[dict], output_root, *, config, header_titl
     )
     created_pages = {
         "all": [
-            Category("Complete bibliography as a single HTML page", "All/index.html")
+            Category(
+                f"Complete list of {header_title.lower()} as a single HTML page",
+                "All/index.html",
+            )
         ],
         "year": write_year_tree(
             entries, output_root / "Year", config=config, header_title=header_title
@@ -564,46 +585,52 @@ def write_html_tree(entries: Sequence[dict], output_root, *, config, header_titl
         yield _get_header(
             f"Index of {header_title}", show_link_to_all=False, show_link_to_index=False
         )
-        yield '<h3 id="years">Selection by year</h3>'
-        yield "<ul>"
-        for name, link in name_sort(created_pages["year"], reverse=True):
-            yield f'<li><a href="{link}">{name}</a></li>'
-        yield "</ul>"
+        if created_pages["year"]:
+            yield '<h3 id="years">Selection by year</h3>'
+            yield "<ul>"
+            for name, link in name_sort(created_pages["year"], reverse=True):
+                yield f'<li><a href="{link}">{name}</a></li>'
+            yield "</ul>"
 
-        yield '<h3 id="categories">Selection by category</h3>'
-        yield "<ul>"
-        for name, link in name_sort(created_pages["category"]):
-            yield f'<li><a href="{link}">{name}</a></li>'
-        yield "</ul>"
+        if created_pages["category"]:
+            yield '<h3 id="categories">Selection by category</h3>'
+            yield "<ul>"
+            for name, link in name_sort(created_pages["category"]):
+                yield f'<li><a href="{link}">{name}</a></li>'
+            yield "</ul>"
 
-        yield '<h3 id="authors">Selection by author</h3>'
-        yield "<ul>"
-        for name, link in name_sort(
-            created_pages["author"], key=lambda e: util.split_name(e)[-1]
-        ):
-            yield f'<li><a href="{link}">{name}</a></li>'
-        yield "</ul>"
+        if created_pages["author"]:
+            yield '<h3 id="authors">Selection by author</h3>'
+            yield "<ul>"
+            for name, link in name_sort(
+                created_pages["author"], key=lambda e: util.split_name(e)[-1]
+            ):
+                yield f'<li><a href="{link}">{_name_to_html(name)}</a></li>'
+            yield "</ul>"
 
-        yield '<h3 id="research_interests">Selection by research interest</h3>'
-        yield "<ul>"
-        for name, link in name_sort(created_pages["keyword"]):
-            yield f'<li><a href="{link}">{name}</a></li>'
-        yield "</ul>"
+        if created_pages["keyword"]:
+            yield '<h3 id="research_interests">Selection by research interest</h3>'
+            yield "<ul>"
+            for name, link in name_sort(created_pages["keyword"]):
+                yield f'<li><a href="{link}">{name}</a></li>'
+            yield "</ul>"
 
-        yield '<h3 id="fundings">Selection by funding</h3>'
-        yield "<ul>"
-        for name, link in name_sort(created_pages["funding"]):
-            yield f'<li><a href="{link}">{name}</a></li>'
-        yield "</ul>"
+        if created_pages["funding"]:
+            yield '<h3 id="fundings">Selection by funding</h3>'
+            yield "<ul>"
+            for name, link in name_sort(created_pages["funding"]):
+                yield f'<li><a href="{link}">{name}</a></li>'
+            yield "</ul>"
 
-        yield '<h3 id="complete">Complete bibliography</h3>'
-        yield "<ul>"
-        for name, link in created_pages["all"]:
-            yield f'<li><a href="{link}">{name}</a></li>'
-        yield "</ul>"
+        if created_pages["all"]:
+            yield f'<h3 id="complete">Complete list of {header_title.lower()}</h3>'
+            yield "<ul>"
+            for name, link in created_pages["all"]:
+                yield f'<li><a href="{link}">{name}</a></li>'
+            yield "</ul>"
 
     with open(output_root / "index.html", "w") as outp:
-        outp.writelines([f"{line}\n" for line in index_page(header_title)])
+        write_html(outp, [f"{line}\n" for line in index_page(header_title)])
 
 
 def write_year_tree(entries: Sequence[dict], output_root, *, config, header_title):
@@ -784,5 +811,7 @@ def _author_to_link(author):
             first_name, _, last_name = author.rpartition("~")
             return f"{last_name.upper()}-{first_name[0].upper()}.html"
         except IndexError:
-            logging.exception("Author-link creation failed for %s", author)
-            return None
+            logging.info(
+                "Author has no first name, author-link may be ambiguous: %s", author
+            )
+            return f"{author.upper()}.html"
